==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/PrimaryKeyValueDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { PrimaryKeyValueDescription } from "./PrimaryKeyValueDescription";
/**
 * @hidden
 */
export let PrimaryKeyValueDescriptionMetadata = /*@__PURE__*/ (() => {
    class PrimaryKeyValueDescriptionMetadata extends Base {
        static b(a) {
            if (PrimaryKeyValueDescriptionMetadata.a == null) {
                PrimaryKeyValueDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                PrimaryKeyValueDescriptionMetadata.c(PrimaryKeyValueDescriptionMetadata.a);
            }
            if (a.k(PrimaryKeyValueDescriptionMetadata.a)) {
                return;
            }
            a.ab(PrimaryKeyValueDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__marshalByValue", "Boolean");
            a.item("Key", "Array:string");
            a.item("Value", "Collection:object:Array:Object");
        }
        static d(a) {
            PrimaryKeyValueDescriptionMetadata.b(a);
            a.ad("PrimaryKeyValue", () => new PrimaryKeyValueDescription());
            a.ac("PrimaryKeyValue", PrimaryKeyValueDescriptionMetadata.a);
        }
    }
    PrimaryKeyValueDescriptionMetadata.$t = markType(PrimaryKeyValueDescriptionMetadata, 'PrimaryKeyValueDescriptionMetadata');
    PrimaryKeyValueDescriptionMetadata.a = null;
    return PrimaryKeyValueDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/PrimaryKeyValueDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { PrimaryKeyValueDescription } from "./PrimaryKeyValueDescription";
/**
 * @hidden
 */
export let PrimaryKeyValueDescriptionMetadata = /*@__PURE__*/ (() => {
    class PrimaryKeyValueDescriptionMetadata extends Base {
        static b(a) {
            if (PrimaryKeyValueDescriptionMetadata.a == null) {
                PrimaryKeyValueDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                PrimaryKeyValueDescriptionMetadata.c(PrimaryKeyValueDescriptionMetadata.a);
            }
            if (a.k(PrimaryKeyValueDescriptionMetadata.a)) {
                return;
            }
            a.ac(PrimaryKeyValueDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__marshalByValue", "Boolean");
            a.item("Key", "Array:string");
            a.item("Value", "Collection:object:Array:Object");
        }
        static d(a) {
            PrimaryKeyValueDescriptionMetadata.b(a);
            a.ae("PrimaryKeyValue", () => new PrimaryKeyValueDescription());
            a.ad("PrimaryKeyValue", PrimaryKeyValueDescriptionMetadata.a);
        }
    }
    PrimaryKeyValueDescriptionMetadata.$t = markType(PrimaryKeyValueDescriptionMetadata, 'PrimaryKeyValueDescriptionMetadata');
    PrimaryKeyValueDescriptionMetadata.a = null;
    return PrimaryKeyValueDescriptionMetadata;
})();
